Contributing
------------

Contributions are wellcome for the implementation of the following
extensions: 

- encoding format beyond json (no specification available);
- transfer protocols (MQTT first); 
- implementation of SLPF ``Actuator``\s for different firewall technologies (both opensource and proprietary);
- implementation of new and draft profiles.

